/***************************************************************
 * Name:      wxextprocess.h
 * Purpose:
 * Author:    Daniel Nell (daniel.nell@nellresearch.de)
 * Created:   2009-05-20
 * Copyright: Daniel Nell (www.nellresearch.de)
 * License:   wxWindows licence
 **************************************************************/

#ifndef WXEXTPROCESS_H
#define WXEXTPROCESS_H

// Include additional wxWidgets headers.
#include <wx/process.h>


//////////////////////////////////////////////////////////
// Class wxExtProcess
//
class wxExtProcess : public wxProcess
{
  public:
    /// ...
    wxExtProcess( wxEvtHandler * poParent, int nId )
      : wxProcess( poParent, nId ), m_nProcessId( 0 )
    {
    }

    /// ...
    virtual ~wxExtProcess(){}

  public:
    virtual long Execute( const wxString& strCommand, int nSync = wxEXEC_ASYNC )
    {
        m_nProcessId= ::wxExecute( strCommand, nSync, this );
        return m_nProcessId;
    }

    virtual void SetProcessId( long nProcessId ){ m_nProcessId= nProcessId; }    ///<...
    virtual long GetProcessId(){ return m_nProcessId; }                          ///<...

    /// ...
    virtual wxKillError Kill( wxSignal nSignal= wxSIGNONE, int nFlags= wxKILL_NOCHILDREN )
    {
        return wxProcess::Kill( GetProcessId(), nSignal, nFlags );
    }

  protected:
    long m_nProcessId;                                                           ///<...
};


//////////////////////////////////////////////////////////
// Class wxReadOutProcess
//
class wxExtProcessDelTempFile : public wxExtProcess
{
  public:
    /// ...
    wxExtProcessDelTempFile( wxEvtHandler * poParent= NULL, int nId = -1, const wxString &strFileName= wxEmptyString )
      : wxExtProcess( poParent, nId )
    {
        m_strFileName= strFileName;
    }

    /// ...
    virtual ~wxExtProcessDelTempFile()
    {
        if( !m_strFileName.IsEmpty() )
        {
            // Remove the temporary file.
            ::wxRemoveFile( m_strFileName );
        }
    }

  protected:
    wxString m_strFileName;
};

#endif // WXEXTPROCESS_H
