/***************************************************************
 * Name:      wxiscanimageprofile.h
 * Purpose:   ...
 * Author:    Daniel Nell (daniel.nell@nellresearch.de)
 * Created:   2009-01-12
 * Copyright: Daniel Nell (www.nellresearch.de)
 * License:   GPL
 **************************************************************/

#include "wx_pch.h"
#include <wx/config.h>

// Private headers
#include "wxiscanimageprofile.h"


wxIScanImageProfile::wxIScanImageProfile( int nProfileIndex, int nResolution )
{
    // Initialize members.
    m_nProfileIndex= nProfileIndex;

    // Get profile configuration.
    wxConfigBase *poConfig= wxConfigBase::Get();

    poConfig->SetRecordDefaults();
    poConfig->SetPath( wxString::Format( wxT( "/Profile/%d" ), m_nProfileIndex ) );

    m_strProfileName= poConfig->Read( wxT( "ProfileName" ), wxString::Format( wxT( "%d" ), m_nProfileIndex ) );
    bCrop= (bool)poConfig->Read( wxT( "Crop" ), (long)false );
    bGreyScale= (bool)poConfig->Read( wxT( "GreyScale" ), (long)false );
    bMonoChrome= (bool)poConfig->Read( wxT( "MonoChrome" ), (long)false );

    x= poConfig->Read( wxT( "x" ), 0L );
    y= poConfig->Read( wxT( "y" ), 0L );
    w= poConfig->Read( wxT( "w" ), (long)( 210.0 / 25.4 * (double)nResolution ) );
    h= poConfig->Read( wxT( "h" ), (long)( 297.0 / 25.4 * (double)nResolution ) );

    nMonoThreshold= poConfig->Read( wxT( "MonoThreshold" ), 128 );
}


wxImage wxIScanImageProfile::ApplyToImage( wxImage oImage )
{
    // Crop image to the profile image rect.
    if( bCrop )
    {
        oImage.Resize( wxSize( w, h ), wxPoint( x, y ), 255, 255, 255 );
    }

    // Convert the image to greyscale.
    if( bGreyScale )
    {
        oImage= oImage.ConvertToGreyscale();
    }

    // Convert the image to mono chrome.
    if( bMonoChrome )
    {
        oImage= oImage.ConvertToGreyscale();
        // ...

        int nCount= oImage.GetWidth() * oImage.GetHeight() * 3;
        unsigned char *pImageDataSrc= oImage.GetData();
        unsigned char *pImageDataDest= (unsigned char *)malloc( nCount * sizeof( unsigned char ) );

        if( !pImageDataDest )
        {
            ::wxLogError( wxString( wxT( "wxIScanImageProfile::ApplyToImage - " ) ) + _( "Cannot allocate memory for pImageDataDest." ) );
            goto leave;
        }

        for( int i= 0; i < nCount; i++ )
        {
            pImageDataDest[i]= ( pImageDataSrc[i] < nMonoThreshold ) ? 0 : 255;
        }

        oImage.SetData( pImageDataDest );
//
//        m_oImage= m_oImage.ConvertToMono( 255, 255, 255 );
    }
leave:
    return oImage;
}
