/////////////////////////////////////////////////////////////////////////////
// Project:     wxIView
// Purpose:     Complex wxWidgets sample
// Name:        wxiviewcanvas.h
// Author:      Daniel Nell
// Created:     2005/10/18
// Copyright:   (c) Daniel Nell
// License:     wxWindows license
// Modified by:
/////////////////////////////////////////////////////////////////////////////

#ifndef __WXIVIEWCANVAS_H
#define __WXIVIEWCANVAS_H


/////////////////////////////////////////////////////////////////////////////
//  Class wxIViewCanvasSizeEvent
//
BEGIN_DECLARE_EVENT_TYPES()
    DECLARE_LOCAL_EVENT_TYPE( wxEVT_IVIEWCANVASSIZE, 0 )
END_DECLARE_EVENT_TYPES()

/////////////////////////////////////////////////////////////////////////////
//  Class wxIViewCanvasSizeEvent
//
/// \brief ... event.
///
/// ...
class wxIViewCanvasSizeEvent : public wxEvent
{
  public:
    /// Constructor
    wxIViewCanvasSizeEvent( wxEventType oType= wxEVT_IVIEWCANVASSIZE ) : wxEvent( 0, oType )
    {
        // Propagate event to the next event handling window.
        m_propagationLevel= wxEVENT_PROPAGATE_MAX;
    }

    /// Return a copy ot this event.
    wxEvent *Clone() const
    {
        return new wxIViewCanvasSizeEvent( *this );
    }
};

typedef void (wxEvtHandler::*wxIViewCanvasSizeEventEventFunction)( wxIViewCanvasSizeEvent& );

#define wxIViewCanvasSizeEventEventHandler(func) \
    (wxObjectEventFunction)(wxEventFunction)wxStaticCastEvent( wxIViewCanvasSizeEventEventFunction, &func )

#define EVT_IVIEWCANVASSIZE(func) \
   wx__DECLARE_EVT0( wxEVT_IVIEWCANVASSIZE, wxIViewCanvasSizeEventEventHandler( func ) )


/////////////////////////////////////////////////////////////////////////////
//  class wxIViewCanvas
//
/// \brief The canvas window
///
/// ...
class wxIViewCanvas: public wxScrolledWindow
{
  protected:
    wxBitmap m_oBitmap;     ///< Internal bitmap object for repainting.

  public:
    /// Default constructor - needed by wxWidgets
    wxIViewCanvas(){}

    /// \brief Standard constructor
    ///
    /// \param poParent      a pointer to the dialog windows's parent window.
    /// \param nId           the window id, default: 1
    /// \param oPos          the window position, default: wxDefaultPosition
    /// \param oSize         the window size, default: wxDefaultSize
    /// \param nStyle        ..., default: wxHSCROLL | wxVSCROLL | wxSUNKEN_BORDER
    /// \param strName       ..., default: wxT( "wxIViewCanvas" )
    wxIViewCanvas( wxWindow *poParent,
                   wxWindowID nId= wxID_ANY,
                   const wxPoint &oPos= wxDefaultPosition,
                   const wxSize &oSize= wxDefaultSize,
                   long nStyle= wxHSCROLL | wxVSCROLL | wxSUNKEN_BORDER,
                   const wxString& strName= wxT( "wxIViewCanvas" )
                 );

    /// Destructor
    virtual ~wxIViewCanvas();

    /// \brief Handler for window (re)painting.
    ///
    ///  Creates and prepares a device context and calls Paint( wxDC& oDc ).
    void OnPaint( wxPaintEvent &oEvent );

    /// Repaints the image (using an internal bitmap).
    virtual bool Paint( wxDC& oDc );

    /// Returns the internal bitmap.
    virtual wxBitmap& GetBitmap(){ return m_oBitmap; }


    /// Sets the internal bitmap.
    virtual void SetBitmap( const wxBitmap &oBitmap );

     /// Handle resizing.
    void OnSize( wxSizeEvent &oEvent );

    /// Handle timer events.
    void OnTimer( wxTimerEvent &oEvent );

  protected:
    // Member variables
    //
    /// Timer for ...
    wxTimer m_oTimer;

  private:
    // Declares wxIViewCanvas for dynamic class creation.
    DECLARE_DYNAMIC_CLASS( wxIViewCanvas )

    // Any class wishing to process wxWindows events must use this macro
    DECLARE_EVENT_TABLE()
};

#endif // __WXIVIEWCANVAS_H
