/***************************************************************
 * Name:      wxpoppler.h
 * Purpose:   Code for pdf file access (for viewing pdf files)
 * Author:    Daniel Nell (daniel.nell@nellresearch.de)
 * Created:   2008-07-08
 * Copyright: Daniel Nell (www.nellresearch.de)
 * License:
 **************************************************************/

#ifndef WXPOPPLER_H
#define WXPOPPLER_H

#include <poppler.h>
#include <wx/image.h>


/////////////////////////////////////////////////////////////////////////////
//  Class wxPoppler
//
/// \brief A class to handle PDF files using libpoppler.
///
/// ...
class wxPoppler
{
  public:
    wxPoppler();                                                            ///< Standard constructor.
    virtual ~wxPoppler();                                                   ///< Destructor.

  public:
    bool Open( const wxString& strFileName ){ return Open( NULL, 0, strFileName ); } ///< Opens a PDF file.
    bool Open( char *pcData, const int nLength ){ return Open( pcData, nLength, wxEmptyString ); } ///< Opens a PDF file in memory.
    int  GetPageCount(){ return poppler_document_get_n_pages( m_pPdfDocument ); } ///< ...
    bool SelectPage( int nIndex );                                          ///< ...
    bool RenderPage();                        ;                             ///< ...
    int  SetDpi( int nDpi ){ int nOldDpi= m_nDpi; m_nDpi= nDpi; return nOldDpi; } ///< ...
    wxImage GetImage(){ return m_oImage; }                                  ///< ...

  protected:
    /// Opens a PDF stream from file or memory.
    bool Open( char *pcData, const int nLength, const wxString& strFileName );

  protected:
    wxImage m_oImage;                                                       ///< Image object rendered by RenderPage().
    int m_nDpi;                                                             ///< ...
    PopplerPage *m_pPdfPage;                                                ///< ...
    PopplerDocument *m_pPdfDocument;                                        ///< ...
};


#if wxUSE_PDF
/////////////////////////////////////////////////////////////////////////////
//  Enum wxBitmapTypePdf
//
/// \brief ...
///
/// ...
enum wxBitmapTypePdf
{
    wxBITMAP_TYPE_PDF = wxBITMAP_TYPE_ANY + 1047
};


/////////////////////////////////////////////////////////////////////////////
//  Class wxPDFHandler
//
/// \brief ...
///
/// ...
class wxPDFHandler : public wxImageHandler
{
  public:
    /// ...
    wxPDFHandler()
      : m_nPageCount( 0 )
    {
        m_name= wxT( "wxPDFHandler" );
        m_extension= wxT( "pdf" );
        m_type= wxBITMAP_TYPE_PDF;
        m_mime= wxT( "application/pdf" );
    }


#if wxUSE_STREAMS
  public:
    /// ...
    virtual bool LoadFile( wxImage* poImage, wxInputStream& oIStream, bool bVerbose= true, int nIndex= 0 );

    /// ...
    virtual bool SaveFile(wxImage* poImage, wxOutputStream& oOStream );

    /// ...
    virtual int GetImageCount( wxInputStream& oIStream ){ return m_nPageCount; }


  protected:
    /// ...
    virtual bool DoCanRead( wxInputStream& oIStream );
#endif // wxUSE_STREAMS

  private:
    int m_nPageCount;

  private:
    DECLARE_DYNAMIC_CLASS( wxPDFHandler )
};
#endif // wxUSE_PDF

#endif // WXPOPPLER_H
